#!/usr/bin/env python

"""
Run the queries described in README

cmd1:env keystore=`pwd` ./query.py 
cmd2: env ABAC_CN=1 keystore=`pwd` ./query.py

"""

import os
import ABAC

ctxt = ABAC.Context()

# Keystore is the directory containing the principal credentials.
# Load existing principals and/or policy credentials
if (os.environ.has_key("keystore")) :
    keystore=os.environ["keystore"]
    ctxt.load_directory(keystore)
else:
    print("keystore is not set...")
    exit(1)

# retrieve principals' keyid value from local credential files
acmeID=ABAC.ID("Acme_ID.pem");
acmeID.id_load_privkey_file("Acme_private.pem");
acme=acmeID.id_keyid()

bobID=ABAC.ID("Bob_ID.pem");
bobID.id_load_privkey_file("Bob_private.pem");
bob=bobID.id_keyid()

aliceID=ABAC.ID("Alice_ID.pem");
aliceID.id_load_privkey_file("Alice_private.pem");
alice=aliceID.id_keyid()

globotronID=ABAC.ID("Globotron_ID.pem");
globotronID.id_load_privkey_file("Globotron_private.pem");
globotron=globotronID.id_keyid()

##########################################################################
# dump the loaded principals/policies
#
out = ctxt.context_principals()
print "\n...final principal set..."
for x in out[1]:
    print "%s " % x.string()
out = ctxt.context_credentials()
print "\n...final policy attribute set..."
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())

def get_next(ctxt) :
    next=1
    while( next ) :
        out = ctxt.next_proof()
        print ("\nnext proof:")
        for c in out[1]:
            print "%s <- %s" % (c.head_string(), c.tail_string())
        else:
            next=0
            print("no more..\n")

##########################################################################
# can bob create experiment at Acme ?
# role=[keyid:Acme].role:experiment_create 
# p=[keyid:Bob]
role = ABAC.Role(acme,"experiment_create")
p = ABAC.Role(bob)
print "\n===good=============== Acme.experiment_create <- Bob"
out = ctxt.query(role, p)
for c in out[1]:
    print "%s <- %s" % (c.head_string(), c.tail_string())
get_next(ctxt)

